OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Систем додао системску ознаку %1$s",
    "Added system tag {systemtag}" : "Додата системска ознака {systemtag}",
    "Added system tag %1$s" : "Додата системска ознака %1$s",
    "%1$s added system tag %2$s" : "%1$s је додао системску ознаку %2$s",
    "{actor} added system tag {systemtag}" : "{actor} је додао системску ознаку {systemtag}",
    "System tag %1$s removed by the system" : "Систем уклонио системску ознаку %1$s",
    "Removed system tag {systemtag}" : "Уклоњена системска ознака {systemtag}",
    "Removed system tag %1$s" : "Уклоњена системска ознака %1$s",
    "%1$s removed system tag %2$s" : "%1$sуклонио системску ознаку %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} уклонио системску ознаку {systemtag}",
    "You created system tag %1$s" : "Направили сте системску ознаку %1$s",
    "You created system tag {systemtag}" : "Направили сте системску ознаку {systemtag}",
    "%1$s created system tag %2$s" : "%1$s направио системску ознаку %2$s",
    "{actor} created system tag {systemtag}" : "{actor} направио системску ознаку {systemtag}",
    "You deleted system tag %1$s" : "Избрисали сте системску ознаку %1$s",
    "You deleted system tag {systemtag}" : "Избрисали сте системску ознаку {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s обрисао системску ознаку %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} обрисао системску ознаку {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ажурирали сте системску ознаку %2$s на %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ажурирали сте системску ознаку {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ажурирао системску ознаку %3$s на %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ажурирао системску ознаку {oldsystemtag} на {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Систем је додао системску ознаку %2$s на %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Систем је додао системску ознаку {systemtag} на {file}",
    "You added system tag %2$s to %1$s" : "Додали сте системску ознаку %2$s на %1$s",
    "You added system tag {systemtag} to {file}" : "Додали сте системску ознаку {systemtag} на {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s додао системску ознаку %3$s на %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} додао системску ознаку {systemtag} на {file}",
    "System tag %2$s was removed from %1$s by the system" : "Систем је уклонио системску ознаку %2$s са фајла %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Систем је уклонио системску ознаку {systemtag} са фајла {file}",
    "You removed system tag %2$s from %1$s" : "Уклонили сте системску ознаку %2$s са %1$s",
    "You removed system tag {systemtag} from {file}" : "Уклонили сте системску ознаку {systemtag} са {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s уклонио системску ознаку %3$s са %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} уклонио системску ознаку {systemtag} са {file}",
    "%s (restricted)" : "%s (ограничена)",
    "%s (invisible)" : "%s (невидљива)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Системске ознаке</strong> за фајл су измењене",
    "Tags" : "Ознаке",
    "All tagged %s …" : "Све означено %s …",
    "tagged %s" : "означено %s",
    "Collaborative tags" : "Тимске ознаке",
    "Collaborative tagging functionality which shares tags among people." : "Могућност заједничког означавања којим се деле ознаке међу људима.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функција заједничког означавања којом се ознаке деле међу људима. Одлично за тимове.\n\t(ако сте пружалац услуге са инсталацијом на више различитих локација, саветује се да искључите ову апликацију пошто се ознаке свакако деле.)",
    "Create or edit tags" : "Креирај или уреди ознаке",
    "Search for a tag to edit" : "Претрага ознаке за уређивање",
    "Collaborative tags …" : "Ознаке сарадње...",
    "No tags to select" : "Нема ниједне ознаке која може да се изабере",
    "Tag name" : "Назив ознаке",
    "Tag level" : "Ниво ознаке",
    "Create" : "Направи",
    "Update" : "Ажурирај",
    "Delete" : "Обриши",
    "Reset" : "Ресетуј",
    "Loading …" : "Учитавање…",
    "Public" : "Јавна",
    "Restricted" : "Ограничена",
    "Invisible" : "Невидљива",
    "Created tag" : "Креирана ознака",
    "Failed to create tag" : "Ознака није могла да се креира",
    "Updated tag" : "Ажурирана ознака",
    "Failed to update tag" : "Није успело ажурирање ознаке",
    "Deleted tag" : "Обрисана ознака",
    "Failed to delete tag" : "Ознака није могла да се обрише",
    "Loading collaborative tags …" : "Учитавају се ознаке сарадње…",
    "Search or create collaborative tags" : "Претражите или креирајте ознаке за сарадњу",
    "No tags to select, type to create a new tag" : "Није изабрана ниједна ознака, куцајте да креирате нову ознаку",
    "Failed to load tags" : "Грешка при учитавању ознака",
    "Failed to load selected tags" : "Изабрана ознака није могла да се учита",
    "Failed to select tag" : "Ознака није могла да се изабере",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Заједниче ознаке су доступне свим корисницима. Заштићене ознаке су доступне свим корисницима, али их они не могу додељивати. Невидљиве ознаке су за интерну употребу, пошто их корисници не могу ни видети ни додељивати.",
    "This file has the tag {tag}" : "Овај фајл има ознаку {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Овај фајл има ознаке {firstTags} и {lastTag}",
    "List of tags and their associated files and folders." : "Листа ознака и њима придружени фајлови и директоријуми.",
    "No tags found" : "Нису нађене ознаке",
    "Tags you have created will show up here." : "Овде ће се појавити ознаке које сте креирали.",
    "Failed to load last used tags" : "Последње коришћена ознака није могла да се учита",
    "Missing \"Content-Location\" header" : "Недостаје Content-Location” заглавље",
    "Failed to load tags for file" : "Није успело учитавање ознака за фајл",
    "Failed to set tag for file" : "Није успело постављање ознака за фајл",
    "Failed to delete tag for file" : "Није успело брисање ознака за фајл",
    "Tag name is empty" : "Име ознаке је празно",
    "Select tag …" : "Одаберите ознаку …",
    "Collaborative tagging functionality which shares tags among users." : "Могућност заједничког означавања којим се деле ознаке међу корисницима.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Могућност заједничког означавања којим се деле ознаке међу корисницима. Сјајно за тимове.\n\t(ако сте провајдер инсталације за одвојене кориснике/предузећа, саветује се да иксључите ову апликацију пошто су ознаке дељене.)",
    "Tagged files" : "Означени фајлови",
    "Select tags to filter by" : "Одаберите ознаке по којима да се филтрира",
    "Please select tags to filter by" : "Одаберите ознаке по којима да се филтрира",
    "No files found for the selected tags" : "Ниједан фајл није нађен за одабране ознаке",
    "Create a new tag" : "Направи нову ознаку",
    "Name" : "Назив",
    "No files in here" : "Овде нема фајлова",
    "No entries found in this folder" : "Нема ничега у овој фасцикли",
    "Size" : "Величина",
    "Modified" : "Измењен"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
